@@ -151,8 +151,14 @@ sub get_vg_information() {
     my $lvn;
     my $pvn;
 
-    if( ! -e "/usr/sbin/vgdisplay" ) { die("LVM utilities not installed in /sbin"); }
-    my @vginfo = `/usr/sbin/vgdisplay -v`;
+    my @vginfo;
+
+    if ( -e "/usr/sbin/vgdisplay" ) {
+        @vginfo = `/usr/sbin/vgdisplay -v`;
+    } else {
+        if( ! -e "/sbin/vgdisplay" ) { die("LVM utilities not installed in /sbin or /usr/sbin"); }
+        @vginfo = `/sbin/vgdisplay -v`;
+    }
 
     VGINF: foreach(@vginfo) {
         chomp;
@@ -325,6 +331,20 @@ sub get_vg_information() {
             $vghash{$vgn}->{lvols}->{$lvn}->{read_ahead} = $1; 
             next VGINF; }
 
+
+        elsif( m/Allocated to snapshot\s+(\S+)%/ ) {
+            $vghash{$vgn}->{lvols}->{$lvn}->{'allocated_to_snapshot'} = $1;
+            next VGINF; }
+
+        elsif( m/COW-table size\s+([0-9\.]+)\s+(\S+)/ ) {
+            $vghash{$vgn}->{lvols}->{$lvn}->{'cow_table_size'} = $1;
+            $vghash{$vgn}->{lvols}->{$lvn}->{'cow_table_unit'} = $2;
+            next VGINF; }
+
+        elsif( m/Mirrored volumes\s+(.+)/ ) {
+                $vghash{$vgn}->{lvols}->{$lvn}->{'mirrored_volumes'} = $1;
+                next VGINF; }
+
         # Parse the physical disk name.
         elsif( m/PV Name\s+(\S+)/ ) {
             $pvn = $1;
@@ -359,10 +379,17 @@ sub get_vg_information() {
 sub get_pv_info($) {
     my $pvname = $_[0];
     my %pvhash;
+    my @pvinfo;
 
     if( ! -e "$pvname" ) { die("Physical Disk: $pvname does not exist."); }
-    if( ! -e "/usr/sbin/pvdisplay" ) { die("LVM utilities not installed in /sbin"); }
-    my @pvinfo = `/usr/sbin/pvdisplay $pvname`;
+
+    if ( -e "/usr/sbin/pvdisplay" ) {
+        @pvinfo = `/usr/sbin/pvdisplay $pvname`;
+    } else {
+        if( ! -e "/sbin/pvdisplay" ) { die("LVM utilities not installed in /sbin or /usr/sbin"); }
+        @pvinfo = `/sbin/pvdisplay $pvname`;
+    }
+
 
     PVINF: foreach(@pvinfo) {
         # Get the name of the physical volume.
@@ -444,9 +471,16 @@ sub get_pv_info($) {
 sub get_lv_info($) {
     my $lvname = $_[0];
     my %lvhash;
+    my @lvinfo;
+
     if( ! -e "$lvname" ) { die("Logical Disk: $lvname does not exist."); }
-    if( ! -e "/usr/sbin/lvdisplay" ) { die("LVM utilities not installed in /sbin"); }
-    my @lvinfo = `/usr/sbin/lvdisplay $lvname`;
+
+    if ( -e "/usr/sbin/vgdisplay" ) {
+        @lvinfo = `/usr/sbin/lvdisplay $lvname`;
+    } else {
+        if( ! -e "/sbin/vgdisplay" ) { die("LVM utilities not installed in /sbin or /usr/sbin"); }
+        @lvinfo = `/sbin/lvdisplay $lvname`;
+    }
 
     LVINF: foreach(@lvinfo) {
 
@@ -515,6 +549,15 @@ sub get_lv_info($) {
         if( m/Block device\s+(\S+)/ ) {
             $lvhash{block_device} = $1;
             next LVINF; }
+
+        if( m/Allocated to snapshot\s+(\S+)%/ ) {
+            $lvhash{allocated_to_snapshot} = $1;
+            next LVINF; }
+
+        elsif( m/COW-table size\s+([0-9\.]+)\s+(\S+)/ ) {
+            $lvhash{'cow_table_size'} = $1;
+            $lvhash{'cow_table_unit'} = $2;
+            next LVINF; }
     }
     return %lvhash;
 } # End of the get_lv_info routine.
